@@ -4,6 +4,9 @@ function(keyword){
       if(grepl("Authorization Error",output)){
         message("Your API credentials are invalid. Please enter valid HTTPS credentials using setCreds().")
       }
+      else if(grepl('total="0"',output)){
+        message("Your keyword returned no results. Please try another keyword or occupational title.")
+      }
       else{
         output <- xmlParse(output)
         keyOutput <- xmlToDataFrame(nodes = getNodeSet(output, "//career"))
